@@ -12,6 +12,11 @@ pub struct BenchmarkResult {
     /// The full command line of the program that is being benchmarked
     pub command: String,
 
+    /// The full command line of the program that is being benchmarked, possibly including a list of
+    /// parameters that were not used in the command line template.
+    #[serde(skip_serializing)]
+    pub command_with_unused_parameters: String,
+
     /// The average run time
     pub mean: Second,
 
