@@ -2,6 +2,8 @@ use std::collections::BTreeMap;
 use std::fmt;
 use std::str::FromStr;
 
+use crate::parameter::tokenize::tokenize;
+use crate::parameter::ParameterValue;
 use crate::{
     error::{OptionsError, ParameterScanError},
     parameter::{
@@ -10,13 +12,9 @@ use crate::{
     },
 };
 
-use clap::ArgMatches;
-
-use crate::parameter::tokenize::tokenize;
-use crate::parameter::ParameterValue;
+use clap::{parser::ValuesRef, ArgMatches};
 
 use anyhow::{bail, Context, Result};
-use clap::Values;
 use rust_decimal::Decimal;
 
 /// A command that should be benchmarked.
@@ -60,6 +58,21 @@ impl<'a> Command<'a> {
         )
     }
 
+    pub fn get_name_with_unused_parameters(&self) -> String {
+        let parameters = self
+            .get_unused_parameters()
+            .map(|(parameter, value)| format!("{} = {}, ", parameter, value.to_string()))
+            .collect::<String>();
+        let parameters = parameters.trim_end_matches(", ");
+        let parameters = if parameters.is_empty() {
+            "".into()
+        } else {
+            format!(" ({})", parameters)
+        };
+
+        format!("{}{}", self.get_name(), parameters)
+    }
+
     pub fn get_command_line(&self) -> String {
         self.replace_parameters_in(self.expression)
     }
@@ -83,6 +96,12 @@ impl<'a> Command<'a> {
         &self.parameters
     }
 
+    pub fn get_unused_parameters(&self) -> impl Iterator<Item = &(&'a str, ParameterValue)> {
+        self.parameters
+            .iter()
+            .filter(move |(parameter, _)| !self.expression.contains(&format!("{{{}}}", parameter)))
+    }
+
     fn replace_parameters_in(&self, original: &str) -> String {
         let mut result = String::new();
         let mut replacements = BTreeMap::<String, String>::new();
@@ -118,21 +137,28 @@ pub struct Commands<'a>(Vec<Command<'a>>);
 
 impl<'a> Commands<'a> {
     pub fn from_cli_arguments(matches: &'a ArgMatches) -> Result<Commands> {
-        let command_names = matches.values_of("command-name");
-        let command_strings = matches.values_of("command").unwrap();
+        let command_names = matches.get_many::<String>("command-name");
+        let command_strings = matches
+            .get_many::<String>("command")
+            .unwrap_or_default()
+            .map(|v| v.as_str())
+            .collect::<Vec<_>>();
 
-        if let Some(args) = matches.values_of("parameter-scan") {
-            let step_size = matches.value_of("parameter-step-size");
+        if let Some(args) = matches.get_many::<String>("parameter-scan") {
+            let step_size = matches
+                .get_one::<String>("parameter-step-size")
+                .map(|s| s.as_str());
             Ok(Self(Self::get_parameter_scan_commands(
                 command_names,
                 command_strings,
                 args,
                 step_size,
             )?))
-        } else if let Some(args) = matches.values_of("parameter-list") {
-            let command_names = command_names.map_or(vec![], |names| names.collect::<Vec<&str>>());
-
-            let args: Vec<_> = args.collect();
+        } else if let Some(args) = matches.get_many::<String>("parameter-list") {
+            let command_names = command_names.map_or(vec![], |names| {
+                names.map(|v| v.as_str()).collect::<Vec<_>>()
+            });
+            let args: Vec<_> = args.map(|v| v.as_str()).collect::<Vec<_>>();
             let param_names_and_values: Vec<(&str, Vec<String>)> = args
                 .chunks_exact(2)
                 .map(|pair| {
@@ -148,9 +174,8 @@ impl<'a> Commands<'a> {
                     bail!("Duplicate parameter names: {}", &duplicates.join(", "));
                 }
             }
-            let command_list = command_strings.collect::<Vec<&str>>();
 
-            let dimensions: Vec<usize> = std::iter::once(command_list.len())
+            let dimensions: Vec<usize> = std::iter::once(command_strings.len())
                 .chain(
                     param_names_and_values
                         .iter()
@@ -191,7 +216,7 @@ impl<'a> Commands<'a> {
                     .collect();
                 commands.push(Command::new_parametrized(
                     name,
-                    command_list[*command_index],
+                    command_strings[*command_index],
                     parameters,
                 ));
 
@@ -209,14 +234,15 @@ impl<'a> Commands<'a> {
 
             Ok(Self(commands))
         } else {
-            let command_names = command_names.map_or(vec![], |names| names.collect::<Vec<&str>>());
+            let command_names = command_names.map_or(vec![], |names| {
+                names.map(|v| v.as_str()).collect::<Vec<_>>()
+            });
             if command_names.len() > command_strings.len() {
                 return Err(OptionsError::TooManyCommandNames(command_strings.len()).into());
             }
 
-            let command_list = command_strings.collect::<Vec<&str>>();
-            let mut commands = Vec::with_capacity(command_list.len());
-            for (i, s) in command_list.iter().enumerate() {
+            let mut commands = Vec::with_capacity(command_strings.len());
+            for (i, s) in command_strings.iter().enumerate() {
                 commands.push(Command::new(command_names.get(i).copied(), s));
             }
             Ok(Self(commands))
@@ -285,16 +311,18 @@ impl<'a> Commands<'a> {
     }
 
     fn get_parameter_scan_commands<'b>(
-        command_names: Option<Values<'b>>,
-        command_strings: Values<'b>,
-        mut vals: clap::Values<'b>,
+        command_names: Option<ValuesRef<'b, String>>,
+        command_strings: Vec<&'b str>,
+        mut vals: ValuesRef<'b, String>,
         step: Option<&str>,
     ) -> Result<Vec<Command<'b>>, ParameterScanError> {
-        let command_names = command_names.map_or(vec![], |names| names.collect::<Vec<&str>>());
-        let command_strings = command_strings.collect::<Vec<&str>>();
-        let param_name = vals.next().unwrap();
-        let param_min = vals.next().unwrap();
-        let param_max = vals.next().unwrap();
+        let command_names = command_names.map_or(vec![], |names| {
+            names.map(|v| v.as_str()).collect::<Vec<_>>()
+        });
+        let command_strings = command_strings;
+        let param_name = vals.next().unwrap().as_str();
+        let param_min = vals.next().unwrap().as_str();
+        let param_max = vals.next().unwrap().as_str();
 
         // attempt to parse as integers
         if let (Ok(param_min), Ok(param_max), Ok(step)) = (
@@ -483,7 +511,7 @@ fn test_parameter_scan_commands_decimal() {
 }
 
 #[test]
-fn test_parameterr_scan_commands_names() {
+fn test_parameter_scan_commands_names() {
     let commands = Commands::build_parameter_scan_commands(
         "val",
         1i32,
